Package: diffuseR
Title: Functional Interface to Diffusion Models in R
Version: 0.2.2
Authors@R: c(
    person("Troy", "Hernandez", email = "troy@cornball.ai", role = c("aut", "cre"),
           comment = c(ORCID = "0009-0005-4248-604X")),
    person("cornball.ai", role = "cph"),
    person("The HuggingFace Team", role = "cph",
           comment = "portions ported from the diffusers library (Apache-2.0); see inst/COPYRIGHTS"),
    person("Lightricks Ltd.", role = "cph",
           comment = "LTX checkpoint layout and pipeline constants; see inst/COPYRIGHTS"))
Description: A native R implementation of diffusion models providing a
    functional interface to state-of-the-art generative AI. Inspired by the
    'Python' library 'diffusers' from 'Hugging Face'
    <https://huggingface.co/>, 'diffuseR' generates and manipulates images
    from text prompts using models such as 'Stable Diffusion', with no
    'Python' dependency. Supports multiple diffusion schedulers and device
    acceleration.
License: Apache License (>= 2)
URL: https://github.com/cornball-ai/diffuseR
BugReports: https://github.com/cornball-ai/diffuseR/issues
Encoding: UTF-8
Imports: torch, jsonlite, grid, png, jpeg
Suggests: av, hfhub, safetensors, simplermarkdown, tinytest
VignetteBuilder: simplermarkdown
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-08-03 06:24:31 UTC; troy
Author: Troy Hernandez [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-4248-604X>),
  cornball.ai [cph],
  The HuggingFace Team [cph] (portions ported from the diffusers library
    (Apache-2.0); see inst/COPYRIGHTS),
  Lightricks Ltd. [cph] (LTX checkpoint layout and pipeline constants;
    see inst/COPYRIGHTS)
Maintainer: Troy Hernandez <troy@cornball.ai>
Repository: CRAN
Date/Publication: 2026-08-08 12:40:02 UTC
