% tinyrox says don't edit this manually, but it can't stop you!
\name{rotate_half}
\alias{rotate_half}
\title{Rotate half of the hidden dims}
\usage{
rotate_half(x)
}
\description{
Rotate half of the hidden dims
}
\keyword{internal}
