% tinyrox says don't edit this manually, but it can't stop you!
\name{UNetCrossAttention}
\alias{UNetCrossAttention}
\title{Cross-Attention for UNet}
\usage{
UNetCrossAttention(query_dim, context_dim = NULL, heads = 8L, dim_head = 64L)
}
\description{
Cross-Attention for UNet
}
\keyword{internal}
