% tinyrox says don't edit this manually, but it can't stop you!
\name{download_flux}
\alias{download_flux}
\title{Download and Prepare FLUX.1-schnell Weights}
\description{
Downloads FLUX.1-schnell from HuggingFace (weights Apache-2.0, but
the repo is gated behind a license click-through) and quantizes the
12B transformer to a local NF4 (~7 GB) or fp8 (~12 GB) artifact.
}
