% tinyrox says don't edit this manually, but it can't stop you!
\name{flowmatch_set_timesteps}
\alias{flowmatch_set_timesteps}
\title{Set timesteps for inference}
\usage{
flowmatch_set_timesteps(schedule, num_inference_steps = 50L, device = "cpu",
                        mu = NULL, sigmas = NULL, timesteps = NULL)
}
\arguments{
\item{schedule}{List. The FlowMatch scheduler object.}

\item{num_inference_steps}{Integer. Number of denoising steps. Default: 50}

\item{device}{Character or torch device. Device for tensors. Default: "cpu"}

\item{mu}{Numeric or NULL. Shift parameter for dynamic shifting. Required
if use_dynamic_shifting is TRUE. Default: NULL}

\item{sigmas}{Numeric vector or NULL. Custom sigma values. Default: NULL}

\item{timesteps}{Numeric vector or NULL}
}
\value{
Updated scheduler with configured timesteps and sigmas.
}
\description{
Configures the scheduler timesteps for a specific number of inference steps.
This must be called before using the scheduler for denoising.
}
