% tinyrox says don't edit this manually, but it can't stop you!
\name{Upsample2D}
\alias{Upsample2D}
\title{Upsample Block}
\usage{
Upsample2D(channels)
}
\description{
Upsample Block
}
\keyword{internal}
