% tinyrox says don't edit this manually, but it can't stop you!
\name{apply_bpe_merges}
\alias{apply_bpe_merges}
\title{Apply BPE merge rules}
\usage{
apply_bpe_merges(tokens, merge_priority, vocab)
}
\description{
Apply BPE merge rules
}
\keyword{internal}
