% tinyrox says don't edit this manually, but it can't stop you!
\name{UNetResBlock}
\alias{UNetResBlock}
\title{ResNet Block for UNet}
\usage{
UNetResBlock(in_channels, out_channels, time_embed_dim)
}
\description{
ResNet Block for UNet
}
\keyword{internal}
