% tinyrox says don't edit this manually, but it can't stop you!
\name{ltx23_census}
\alias{ltx23_census}
\title{Summarize checkpoint key coverage}
\usage{
ltx23_census(ckpt)
}
\arguments{
\item{ckpt}{An \code{ltx23_checkpoint}.}
}
\value{
A data.frame with one row per component group and its key count.
}
\description{
Summarize checkpoint key coverage
}
