% tinyrox says don't edit this manually, but it can't stop you!
\name{GEGLU}
\alias{GEGLU}
\title{GEGLU Feedforward}
\usage{
GEGLU(dim_in, dim_out)
}
\description{
GEGLU Feedforward
}
\keyword{internal}
