% tinyrox says don't edit this manually, but it can't stop you!
\name{gemma3_rotary_embedding}
\alias{gemma3_rotary_embedding}
\title{Gemma3 Rotary Position Embeddings}
\usage{
gemma3_rotary_embedding(dim, max_position_embeddings = 8192L, base = 10000,
                        scaling_factor = 1)
}
\arguments{
\item{dim}{Integer. Head dimension.}

\item{max_position_embeddings}{Integer. Maximum sequence length.}

\item{base}{Numeric. RoPE base frequency.}

\item{scaling_factor}{Numeric. Optional scaling factor for extended context.}
}
\description{
Standard RoPE with optional scaling factor for extended context.
}
\keyword{internal}
