% tinyrox says don't edit this manually, but it can't stop you!
\name{.ffmpeg_available}
\alias{.ffmpeg_available}
\title{Check if FFmpeg is Available}
\usage{
.ffmpeg_available()
}
\value{
Logical. TRUE if ffmpeg is in PATH.
}
\description{
Check if FFmpeg is Available
}
\keyword{internal}
