% tinyrox says don't edit this manually, but it can't stop you!
\name{Downsample2D}
\alias{Downsample2D}
\title{Downsample Block}
\usage{
Downsample2D(channels)
}
\description{
Downsample Block
}
\keyword{internal}
