% tinyrox says don't edit this manually, but it can't stop you!
\name{VAEMidBlock}
\alias{VAEMidBlock}
\title{VAE Mid Block}
\usage{
VAEMidBlock(channels, norm_groups = 32)
}
\arguments{
\item{channels}{Number of channels}
}
\description{
VAE Mid Block
}
\keyword{internal}
