% tinyrox says don't edit this manually, but it can't stop you!
\name{get_bos_id}
\alias{get_bos_id}
\title{Get BOS token ID}
\usage{
get_bos_id(tokenizer)
}
\description{
Get BOS token ID
}
\keyword{internal}
