% tinyrox says don't edit this manually, but it can't stop you!
\name{quick_gelu}
\alias{quick_gelu}
\title{QuickGELU activation}
\usage{
quick_gelu(x)
}
\arguments{
\item{x}{Input tensor}
}
\description{
GELU approximation used by OpenAI CLIP: x * sigmoid(1.702 * x)
}
\keyword{internal}
