% tinyrox says don't edit this manually, but it can't stop you!
\name{unet_modules}
\alias{unet_modules}
\title{UNet Modules for Diffusion Models}
\description{
Native R torch modules for UNet architecture.
}
\keyword{internal}
