% tinyrox says don't edit this manually, but it can't stop you!
\name{encode_single}
\alias{encode_single}
\title{Encode a single text string}
\usage{
encode_single(tokenizer, text, add_special_tokens = TRUE)
}
\description{
Encode a single text string
}
\keyword{internal}
