% tinyrox says don't edit this manually, but it can't stop you!
\name{load_gemma3_weights}
\alias{load_gemma3_weights}
\title{Load weights into Gemma3 model}
\usage{
load_gemma3_weights(model, weights, verbose = TRUE)
}
\description{
Load weights into Gemma3 model
}
\keyword{internal}
