% tinyrox says don't edit this manually, but it can't stop you!
\name{group_norm_32}
\alias{group_norm_32}
\title{Group Normalization (32 groups)}
\usage{
group_norm_32(channels)
}
\description{
Group Normalization (32 groups)
}
\keyword{internal}
