% tinyrox says don't edit this manually, but it can't stop you!
\name{BasicTransformerBlock}
\alias{BasicTransformerBlock}
\title{Basic Transformer Block}
\usage{
BasicTransformerBlock(dim, n_heads, d_head, context_dim = NULL)
}
\description{
Basic Transformer Block
}
\keyword{internal}
