% tinyrox says don't edit this manually, but it can't stop you!
\name{vocab_size}
\alias{vocab_size}
\title{Get vocabulary size}
\usage{
vocab_size(tokenizer)
}
\arguments{
\item{tokenizer}{A bpe_tokenizer object.}
}
\value{
Integer vocabulary size.
}
\description{
Get vocabulary size
}
