% tinyrox says don't edit this manually, but it can't stop you!
\name{FeedForward}
\alias{FeedForward}
\title{FeedForward Network}
\usage{
FeedForward(dim, mult = 4L)
}
\description{
FeedForward Network
}
\keyword{internal}
