% tinyrox says don't edit this manually, but it can't stop you!
\name{get_eos_id}
\alias{get_eos_id}
\title{Get EOS token ID}
\usage{
get_eos_id(tokenizer)
}
\description{
Get EOS token ID
}
\keyword{internal}
