% tinyrox says don't edit this manually, but it can't stop you!
\name{ltx23_stage2_distilled_sigmas}
\alias{ltx23_stage2_distilled_sigmas}
\title{Stage-2 distilled sigma schedule (two-stage refinement)}
\usage{
ltx23_stage2_distilled_sigmas()
}
\value{
Numeric vector of length 4.
}
\description{
Stage-2 distilled sigma schedule (two-stage refinement)
}
