% tinyrox says don't edit this manually, but it can't stop you!
\name{get_pad_id}
\alias{get_pad_id}
\title{Get padding token ID}
\usage{
get_pad_id(tokenizer)
}
\description{
Get padding token ID
}
\keyword{internal}
