% tinyrox says don't edit this manually, but it can't stop you!
\name{flowmatch_calculate_shift}
\alias{flowmatch_calculate_shift}
\title{Calculate shift for dynamic shifting}
\usage{
flowmatch_calculate_shift(seq_len, base_seq_len = 256L, max_seq_len = 4096L,
                          base_shift = 0.5, max_shift = 1.15)
}
\arguments{
\item{seq_len}{Integer. The sequence length (num_patches).}

\item{base_seq_len}{Integer. Base sequence length. Default: 256}

\item{max_seq_len}{Integer. Maximum sequence length. Default: 4096}

\item{base_shift}{Numeric. Base shift value. Default: 0.5}

\item{max_shift}{Numeric. Maximum shift value. Default: 1.15}
}
\value{
Numeric. The computed shift value (mu).
}
\description{
Computes the shift parameter (mu) based on sequence length for
resolution-dependent timestep shifting.
}
